"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ramda_1 = require("ramda");
var configurationError_1 = require("../errors/configurationError");
var logger_1 = require("../common/logger");
var PactNative = require("../native/index.node");
var VerifierV3 = /** @class */ (function () {
    function VerifierV3(config) {
        this.config = config;
    }
    /**
     * Verify a HTTP Provider
     */
    VerifierV3.prototype.verifyProvider = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (ramda_1.isEmpty(_this.config)) {
                reject(new configurationError_1.default("No configuration provided to verifier"));
            }
            if (!_this.config.provider) {
                reject(new configurationError_1.default("Provider name is required"));
            }
            if (ramda_1.isEmpty(_this.config.pactUrls) && !_this.config.pactBrokerUrl) {
                reject(new configurationError_1.default("Either a list of pactUrls or a pactBrokerUrl must be provided"));
            }
            try {
                PactNative.verify_provider(_this.config, function (err, val) {
                    if (err || !val) {
                        logger_1.default.debug("In verify_provider callback: FAILED with", err, val);
                        reject(err);
                    }
                    else {
                        logger_1.default.debug("In verify_provider callback: SUCCEEDED with", val);
                        resolve(val);
                    }
                });
                logger_1.default.debug("Submitted test to verify_provider");
            }
            catch (e) {
                reject(e);
            }
        });
    };
    return VerifierV3;
}());
exports.VerifierV3 = VerifierV3;
//# sourceMappingURL=verifier.js.map